@@ -3,6 +3,8 @@ import os.path
 import pickle
 
 import numpy as np
+import torch.distributed as dist
+from mmcv.runner import get_dist_info
 
 from .base_dataset import BaseDataset
 from .builder import DATASETS
@@ -14,8 +16,8 @@ class CIFAR10(BaseDataset):
     """`CIFAR10 <https://www.cs.toronto.edu/~kriz/cifar.html>`_ Dataset.
 
     This implementation is modified from
-    https://github.com/pytorch/vision/blob/master/torchvision/datasets/cifar.py  # noqa: E501
-    """
+    https://github.com/pytorch/vision/blob/master/torchvision/datasets/cifar.py
+    """  # noqa: E501
 
     base_folder = 'cifar-10-batches-py'
     url = 'https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz'
@@ -40,13 +42,21 @@ class CIFAR10(BaseDataset):
 
     def load_annotations(self):
 
-        if not self._check_integrity():
+        rank, world_size = get_dist_info()
+
+        if rank == 0 and not self._check_integrity():
             download_and_extract_archive(
                 self.url,
                 self.data_prefix,
                 filename=self.filename,
                 md5=self.tgz_md5)
 
+        if world_size > 1:
+            dist.barrier()
+            assert self._check_integrity(), \
+                'Shared storage seems unavailable. ' \
+                f'Please download the dataset manually through {self.url}.'
+
         if not self.test_mode:
             downloaded_list = self.train_list
         else:
