@@ -1,7 +1,7 @@
 from .alexnet import AlexNet
 from .lenet import LeNet5
 from .mobilenet_v2 import MobileNetV2
-from .mobilenet_v3 import MobileNetv3
+from .mobilenet_v3 import MobileNetV3
 from .regnet import RegNet
 from .resnest import ResNeSt
 from .resnet import ResNet, ResNetV1d
@@ -11,10 +11,14 @@ from .seresnet import SEResNet
 from .seresnext import SEResNeXt
 from .shufflenet_v1 import ShuffleNetV1
 from .shufflenet_v2 import ShuffleNetV2
+from .swin_transformer import SwinTransformer
+from .tnt import TNT
 from .vgg import VGG
+from .vision_transformer import VisionTransformer
 
 __all__ = [
     'LeNet5', 'AlexNet', 'VGG', 'RegNet', 'ResNet', 'ResNeXt', 'ResNetV1d',
     'ResNeSt', 'ResNet_CIFAR', 'SEResNet', 'SEResNeXt', 'ShuffleNetV1',
-    'ShuffleNetV2', 'MobileNetV2', 'MobileNetv3'
+    'ShuffleNetV2', 'MobileNetV2', 'MobileNetV3', 'VisionTransformer',
+    'SwinTransformer', 'TNT'
 ]
