@@ -260,7 +260,7 @@ class Bottleneck(_Bottleneck):
 class ResNeSt(ResNetV1d):
     """ResNeSt backbone.
 
-    Please refer to the `paper <https://arxiv.org/pdf/2004.08955.pdf>`_ for
+    Please refer to the `paper <https://arxiv.org/pdf/2004.08955.pdf>`__ for
     details.
 
     Args:
