@@ -1,9 +1,9 @@
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-from mmcv.cnn import normal_init
 
 from ..builder import HEADS
+from ..utils import is_tracing
 from .cls_head import ClsHead
 
 
@@ -15,10 +15,18 @@ class LinearClsHead(ClsHead):
         num_classes (int): Number of categories excluding the background
             category.
         in_channels (int): Number of channels in the input feature map.
+        init_cfg (dict | optional): The extra init config of layers.
+            Defaults to use dict(type='Normal', layer='Linear', std=0.01).
     """
 
-    def __init__(self, num_classes, in_channels, *args, **kwargs):
-        super(LinearClsHead, self).__init__(*args, **kwargs)
+    def __init__(self,
+                 num_classes,
+                 in_channels,
+                 init_cfg=dict(type='Normal', layer='Linear', std=0.01),
+                 *args,
+                 **kwargs):
+        super(LinearClsHead, self).__init__(init_cfg=init_cfg, *args, **kwargs)
+
         self.in_channels = in_channels
         self.num_classes = num_classes
 
@@ -26,21 +34,17 @@ class LinearClsHead(ClsHead):
             raise ValueError(
                 f'num_classes={num_classes} must be a positive integer')
 
-        self._init_layers()
-
-    def _init_layers(self):
         self.fc = nn.Linear(self.in_channels, self.num_classes)
 
-    def init_weights(self):
-        normal_init(self.fc, mean=0, std=0.01, bias=0)
-
     def simple_test(self, img):
         """Test without augmentation."""
         cls_score = self.fc(img)
         if isinstance(cls_score, list):
             cls_score = sum(cls_score) / float(len(cls_score))
         pred = F.softmax(cls_score, dim=1) if cls_score is not None else None
-        if torch.onnx.is_in_onnx_export():
+
+        on_trace = is_tracing()
+        if torch.onnx.is_in_onnx_export() or on_trace:
             return pred
         pred = list(pred.detach().cpu().numpy())
         return pred
