@@ -1,9 +1,9 @@
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-from mmcv.cnn import normal_init
 
 from ..builder import HEADS
+from ..utils import is_tracing
 from .multi_label_head import MultiLabelClsHead
 
 
@@ -15,6 +15,8 @@ class MultiLabelLinearClsHead(MultiLabelClsHead):
         num_classes (int): Number of categories.
         in_channels (int): Number of channels in the input feature map.
         loss (dict): Config of classification loss.
+        init_cfg (dict | optional): The extra init config of layers.
+            Defaults to use dict(type='Normal', layer='Linear', std=0.01).
     """
 
     def __init__(self,
@@ -24,8 +26,10 @@ class MultiLabelLinearClsHead(MultiLabelClsHead):
                      type='CrossEntropyLoss',
                      use_sigmoid=True,
                      reduction='mean',
-                     loss_weight=1.0)):
-        super(MultiLabelLinearClsHead, self).__init__(loss=loss)
+                     loss_weight=1.0),
+                 init_cfg=dict(type='Normal', layer='Linear', std=0.01)):
+        super(MultiLabelLinearClsHead, self).__init__(
+            loss=loss, init_cfg=init_cfg)
 
         if num_classes <= 0:
             raise ValueError(
@@ -33,14 +37,9 @@ class MultiLabelLinearClsHead(MultiLabelClsHead):
 
         self.in_channels = in_channels
         self.num_classes = num_classes
-        self._init_layers()
 
-    def _init_layers(self):
         self.fc = nn.Linear(self.in_channels, self.num_classes)
 
-    def init_weights(self):
-        normal_init(self.fc, mean=0, std=0.01, bias=0)
-
     def forward_train(self, x, gt_label):
         gt_label = gt_label.type_as(x)
         cls_score = self.fc(x)
@@ -53,7 +52,9 @@ class MultiLabelLinearClsHead(MultiLabelClsHead):
         if isinstance(cls_score, list):
             cls_score = sum(cls_score) / float(len(cls_score))
         pred = F.sigmoid(cls_score) if cls_score is not None else None
-        if torch.onnx.is_in_onnx_export():
+
+        on_trace = is_tracing()
+        if torch.onnx.is_in_onnx_export() or on_trace:
             return pred
         pred = list(pred.detach().cpu().numpy())
         return pred
