@@ -6,6 +6,7 @@ import torch.nn.functional as F
 from mmcv.cnn import build_activation_layer, constant_init, kaiming_init
 
 from ..builder import HEADS
+from ..utils import is_tracing
 from .cls_head import ClsHead
 
 
@@ -21,22 +22,16 @@ class VisionTransformerClsHead(ClsHead):
             available during pre-training. Default None.
         act_cfg (dict): The activation config. Only available during
             pre-training. Defalut Tanh.
-        loss (dict): Config of classification loss.
-        topk (int | tuple): Top-k accuracy.
-        cal_acc (bool): Whether to calculate accuracy during training.
-            If mixup is used, this should be False. Default False.
-    """  # noqa: W605
+    """
 
     def __init__(self,
                  num_classes,
                  in_channels,
                  hidden_dim=None,
                  act_cfg=dict(type='Tanh'),
-                 loss=dict(type='CrossEntropyLoss', loss_weight=1.0),
-                 topk=(1, ),
-                 cal_acc=False):
-        super(VisionTransformerClsHead, self).__init__(
-            loss=loss, topk=topk, cal_acc=cal_acc)
+                 *args,
+                 **kwargs):
+        super(VisionTransformerClsHead, self).__init__(*args, **kwargs)
         self.in_channels = in_channels
         self.num_classes = num_classes
         self.hidden_dim = hidden_dim
@@ -60,6 +55,7 @@ class VisionTransformerClsHead(ClsHead):
         self.layers = nn.Sequential(OrderedDict(layers))
 
     def init_weights(self):
+        super(VisionTransformerClsHead, self).init_weights()
         # Modified from ClassyVision
         if hasattr(self.layers, 'pre_logits'):
             # Lecun norm
@@ -73,7 +69,9 @@ class VisionTransformerClsHead(ClsHead):
         if isinstance(cls_score, list):
             cls_score = sum(cls_score) / float(len(cls_score))
         pred = F.softmax(cls_score, dim=1) if cls_score is not None else None
-        if torch.onnx.is_in_onnx_export():
+
+        on_trace = is_tracing()
+        if torch.onnx.is_in_onnx_export() or on_trace:
             return pred
         pred = list(pred.detach().cpu().numpy())
         return pred
