@@ -70,16 +70,16 @@ def binary_cross_entropy(pred,
                          weight=None,
                          reduction='mean',
                          avg_factor=None):
-    """Calculate the binary CrossEntropy loss with logits.
+    r"""Calculate the binary CrossEntropy loss with logits.
 
     Args:
-        pred (torch.Tensor): The prediction with shape (N, *).
-        label (torch.Tensor): The gt label with shape (N, *).
+        pred (torch.Tensor): The prediction with shape (N, \*).
+        label (torch.Tensor): The gt label with shape (N, \*).
         weight (torch.Tensor, optional): Element-wise weight of loss with shape
-             (N, ). Defaults to None.
+            (N, ). Defaults to None.
         reduction (str): The method used to reduce the loss.
             Options are "none", "mean" and "sum". If reduction is 'none' , loss
-             is same shape as pred and label. Defaults to 'mean'.
+            is same shape as pred and label. Defaults to 'mean'.
         avg_factor (int, optional): Average factor that is used to average
             the loss. Defaults to None.
 
